---------------------------
-- Tooltip handlers
---------------------------
local tooltip_timer = Timer()
local function enterwindow(self)
    if not ShowTooltips then return end
    tooltip_timer:SetTimeout(1000, function()
        local text = self.tooltip
        if text == "" then return end
        local xres = tonumber(PR.GUI.MainDialog.w)
        local yres = tonumber(PR.GUI.MainDialog.h)
        local selfx = tonumber(self.x)
        local selfy = tonumber(self.y)
        local selfh = tonumber(self.h)
        local newx = selfx + tonumber(self.w)
        local newy = selfy + selfh
        if newy > yres then newy = selfy - selfh end
        ShowTooltip(newx, newy, text)
        local newtooltipwidth = tonumber(ToolTip.w)
        local newtooltipy = tonumber(ToolTip.y)
        if (newx - selfx - newtooltipwidth) < 0 then
            newx = tonumber(self.w)
        end
        if ((newtooltipwidth + newx) >= xres) or (newtooltipy < 0) or
            ((newx - selfx - newtooltipwidth) < 0) then
            if (newtooltipwidth + newx) >= xres then
                newx = -newx
            elseif (newx - selfx - newtooltipwidth) < 0 then
                newx = selfx
            end
            if newtooltipy < 0 then
                newy = selfy - selfh
            end
            ShowTooltip(newx, newy, text)
        end
    end)
end

local function leavewindow(self)
    HideTooltip()
    tooltip_timer:Kill()
end

---------------------------
-- Main Dialog
---------------------------

PR.GUI.Btn_Top1 = iup.stationbutton { title = "", expand = "HORIZONTAL",
    tooltip = "", touchhover = (HasTouchScreen and "YES"),
    enterwindow_cb = enterwindow, leavewindow_cb = leavewindow, }
PR.GUI.Btn_Top2 = iup.stationbutton { title = "", expand = "HORIZONTAL",
    tooltip = "", touchhover = (HasTouchScreen and "YES"),
    enterwindow_cb = enterwindow, leavewindow_cb = leavewindow, }
PR.GUI.Btn_Top3 = iup.stationbutton { title = "", expand = "HORIZONTAL",
    tooltip = "", touchhover = (HasTouchScreen and "YES"),
    enterwindow_cb = enterwindow, leavewindow_cb = leavewindow, }
PR.GUI.Btn_Top4 = iup.stationbutton { title = "", expand = "HORIZONTAL",
    tooltip = "", touchhover = (HasTouchScreen and "YES"),
    enterwindow_cb = enterwindow, leavewindow_cb = leavewindow, }

PR.GUI.DisplayPanel = iup.matrix {
    expand = "YES", bgcolor = "0 0 0 0 *", marginx = 6, marginy = 2,
    image = IMAGE_DIR .. "pda_sub_sub_tab_listbox_border.png",
}

PR.GUI.Btn_Bottom1 = iup.stationbutton {
    title = "Save Settings", expand = "HORIZONTAL",
    tooltip = "Save current GUI state and settings configured in Config view",
    touchhover = (HasTouchScreen and "YES"),
    enterwindow_cb = enterwindow, leavewindow_cb = leavewindow,
}
PR.GUI.Btn_Bottom2 = iup.stationbutton { title = "Close",
    expand = "HORIZONTAL",
    tooltip = "Close this window",
    touchhover = (HasTouchScreen and "YES"),
    enterwindow_cb = enterwindow, leavewindow_cb = leavewindow,
}
PR.GUI.Btn_Bottom3 = iup.stationbutton { title = "Reset Sector",
    expand = "HORIZONTAL",
    fgcolor = PR.GUI.Color.Red,
    tooltip = "",
    touchhover = (HasTouchScreen and "YES"),
    enterwindow_cb = enterwindow, leavewindow_cb = leavewindow,
}

PR.GUI.UserInput = iup.text {
    fgcolor = PR.GUI.Color.Gray,
    expand = "HORIZONTAL",
    tooltip = "Edit selected option value",
    touchhover = (HasTouchScreen and "YES"),
    enterwindow_cb = enterwindow, leavewindow_cb = leavewindow,
}
PR.GUI.Btn_Plus = iup.stationbutton { title = "+100",
    tooltip = "Increase selected option value by 100",
    touchhover = (HasTouchScreen and "YES"),
    enterwindow_cb = enterwindow, leavewindow_cb = leavewindow,
}
PR.GUI.Btn_Minus = iup.stationbutton { title = "-100",
    tooltip = "Decrease selected option value by 100",
    touchhover = (HasTouchScreen and "YES"),
    enterwindow_cb = enterwindow, leavewindow_cb = leavewindow,
}

PR.GUI.EditBox = iup.hbox {
    PR.GUI.UserInput,
    PR.GUI.Btn_Plus,
    PR.GUI.Btn_Minus
}

PR.GUI.MainDialog = iup.dialog {
    iup.vbox {
        iup.hbox {
            PR.GUI.Btn_Top1,
            PR.GUI.Btn_Top2,
            PR.GUI.Btn_Top3,
            PR.GUI.Btn_Top4,
        },
        PR.GUI.DisplayPanel,
        iup.hbox {
            PR.GUI.Btn_Bottom1,
            PR.GUI.Btn_Bottom2,
            PR.GUI.Btn_Bottom3
        },
    },
    title = PR.PluginTitle,
    size = tostring(Font.Default * 38) .. "x%85",
    topmost = "YES",
    resize = "NO",
    menubox = "YES",
    defaultesc = PR.GUI.Btn_Bottom2,
}
PR.GUI.MainDialog:map()

----------------------------
-- Reset Confirmation Dialog
----------------------------

PR.GUI.Btn_ConfirmationReset = iup.stationbutton {
    title = "Reset all data for current sector",
    expand = "HORIZONTAL",
    fgcolor = PR.GUI.Color.Red
}

PR.GUI.Btn_ConfirmationCancel = iup.stationbutton {
    title = "Cancel",
    expand = "HORIZONTAL"
}

PR.GUI.ConfirmationDialog = iup.dialog {
    iup.vbox {
        iup.hbox {
            expand = "HORIZONTAL",
            PR.GUI.Btn_ConfirmationCancel,
            PR.GUI.Btn_ConfirmationReset
        }
    },
    title = "Are you sure?",
    topmost = "YES",
    resize = "NO",
    defaultenter = PR.GUI.Btn_ConfirmationCancel,
    defaultesc = PR.GUI.Btn_ConfirmationCancel,
    parentdialog = PR.GUI.MainDialog,
}
